@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import AssetsMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -64,10 +64,7 @@ class Set(WMLResource):
         else:
             space_endpoint = self._client.service_instance._href_definitions.get_space_href(space_uid)
 
-        if not self._ICP:
-            space_details = requests.get(space_endpoint, headers=self._client._get_headers())
-        else:
-            space_details = requests.get(space_endpoint, headers=self._client._get_headers(), verify=False)
+        space_details = requests.get(space_endpoint, headers=self._client._get_headers())
 
         if space_details.status_code == 404:
             error_msg = "Space with id '{}' does not exist".format(space_uid)
@@ -135,7 +132,7 @@ class Set(WMLResource):
                 self._client.default_space_id = None
 
                 project_endpoint = self._client.service_instance._href_definitions.get_project_href(project_id)
-                project_details = requests.get(project_endpoint, headers=self._client._get_headers(), verify=False)
+                project_details = requests.get(project_endpoint, headers=self._client._get_headers())
                 if project_details.status_code != 200 and project_details.status_code != 204:
                     raise CannotSetProjectOrSpace(reason=project_details.text)
                 else:
