@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 
 from ibm_watson_machine_learning.messages.messages import Messages
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
@@ -60,12 +60,8 @@ class Assets(WMLResource):
         Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, False)
 
         if asset_uid:
-            if not self._ICP and not self._client.WSD:
-                response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
-                                        headers=self._client._get_headers())
-            else:
-                response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
-                                          headers=self._client._get_headers(), verify=False)
+            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
+                                    headers=self._client._get_headers())
 
             return self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
 
@@ -76,16 +72,10 @@ class Assets(WMLResource):
                 "query": "*:*"
             }
 
-            if not self._ICP and not self._client.WSD:
-                response = requests.post(href,
-                                        json=data,
-                                        params=self._client._params(),
-                                        headers=self._client._get_headers())
-            else:
-                response = requests.post(href,
-                                        json=data,
-                                        params=self._client._params(),
-                                        headers=self._client._get_headers(), verify=False)
+            response = requests.post(href,
+                                    json=data,
+                                    params=self._client._params(),
+                                    headers=self._client._get_headers())
 
             return {'resources': [
                 self._get_required_element_from_response(x)
@@ -236,21 +226,12 @@ class Assets(WMLResource):
             return self._get_required_element_from_response(details)
         else:
 
-            if not self._ICP:
-                creation_response = requests.post(
-                        self._client.service_instance._href_definitions.get_data_assets_href(),
-                        headers=self._client._get_headers(),
-                        params = self._client._params(),
-                        json=asset_meta
-                )
-            else:
-                creation_response = requests.post(
+            creation_response = requests.post(
                     self._client.service_instance._href_definitions.get_data_assets_href(),
                     headers=self._client._get_headers(),
-                    json=asset_meta,
-                    params=self._client._params(),
-                    verify=False
-                )
+                    params = self._client._params(),
+                    json=asset_meta
+            )
 
 
             asset_details = self._handle_response(201, u'creating new asset', creation_response)
@@ -268,21 +249,12 @@ class Assets(WMLResource):
                                             "connection_path": file_path,
                                             "is_remote": True})
 
-                if not self._ICP:
-                    attachment_response = requests.post(
-                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
-                        headers=self._client._get_headers(),
-                        params=self._client._params(),
-                        json=attachment_meta
-                    )
-                else:
-                    attachment_response = requests.post(
-                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
-                        headers=self._client._get_headers(),
-                        json=attachment_meta,
-                        params=self._client._params(),
-                        verify=False
-                    )
+                attachment_response = requests.post(
+                    self._client.service_instance._href_definitions.get_attachments_href(asset_id),
+                    headers=self._client._get_headers(),
+                    params=self._client._params(),
+                    json=attachment_meta
+                )
                 attachment_details = self._handle_response(201, u'creating new attachment', attachment_response)
                 if attachment_response.status_code == 201:
                     if connection_id is None:
@@ -298,8 +270,7 @@ class Assets(WMLResource):
                             else:
                                     put_response = requests.put(
                                         self._wml_credentials['url'] + attachment_url,
-                                        files={'file': _file},
-                                        verify=False
+                                        files={'file': _file}
                                     )
                         if put_response.status_code == 201 or put_response.status_code == 200:
                             # Step4: Complete attachment
@@ -315,8 +286,7 @@ class Assets(WMLResource):
                                 complete_response = requests.post(
                                     self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
                                     headers=self._client._get_headers(),
-                                    params=self._client._params(),
-                                    verify=False
+                                    params=self._client._params()
                                 )
                             if complete_response.status_code == 200:
                                 print(Messages.get_message(message_id="success"))
@@ -366,10 +336,7 @@ class Assets(WMLResource):
         if limit is not None:
             data.update({"limit": limit})
 
-        if not self._ICP and not self._client.WSD:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
-        else:
-            response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data, verify=False)
+        response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(),json=data)
         self._handle_response(200, u'list assets', response)
         asset_details = self._handle_response(200, u'list assets', response)["results"]
         space_values = [
@@ -440,14 +407,9 @@ class Assets(WMLResource):
         Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
         import urllib
-        if not self._ICP and not self._client.WSD:
-            asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
-                                          params=self._client._params(),
-                                          headers=self._client._get_headers())
-        else:
-            asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
-                                          params=self._client._params(),
-                                          headers=self._client._get_headers(), verify=False)
+        asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
+                                      params=self._client._params(),
+                                      headers=self._client._get_headers())
         asset_details = self._handle_response(200, u'get assets', asset_response)
 
         if self._WSD:
@@ -456,19 +418,16 @@ class Assets(WMLResource):
                                    urllib.parse.quote('data_asset/' + attachment_url, safe='')
 
             r = requests.get(artifact_content_url, params=self._client._params(), headers=self._client._get_headers(),
-                             stream=True, verify=False)
+                             stream=True)
             if r.status_code != 200:
                 raise ApiRequestFailure(Messages.get_message(message_id="failure_during_downloading_data_asset"), r)
 
             return r.content
         else:
             attachment_id = asset_details["attachments"][0]["id"]
-            if not self._ICP and not self._client.WSD:
-                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=self._client._params(),
-                                        headers=self._client._get_headers())
-            else:
-                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=self._client._params(),
-                                          headers=self._client._get_headers(), verify=False)
+            response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id),
+                                    params=self._client._params(),
+                                    headers=self._client._get_headers())
             if response.status_code == 200:
                 if 'connection_id' in asset_details["attachments"][0] and \
                         asset_details["attachments"][0]['connection_id'] is not None:
@@ -478,11 +437,7 @@ class Assets(WMLResource):
                     cos_conn_data_source_id = self._client.connections.get_datasource_type_uid_by_name('cloudobjectstorage')
                     if attachment_data_source_type == cos_conn_data_source_id:
                         attachment_signed_url = response.json()["url"]
-                        if not self._ICP:
-                            att_response = requests.get(attachment_signed_url)
-                        else:
-                            att_response = requests.get(attachment_signed_url,
-                                                        verify=False)
+                        att_response = requests.get(attachment_signed_url)
                     else:
                         raise WMLClientError(Messages.get_message(message_id="download_api_not_supported_for_this_connection_type"))
                 else:
@@ -493,8 +448,7 @@ class Assets(WMLResource):
                         else:
                             att_response = requests.get(self._wml_credentials["url"]+attachment_signed_url)
                     else:
-                        att_response = requests.get(self._wml_credentials["url"]+attachment_signed_url,
-                                                verify=False)
+                        att_response = requests.get(self._wml_credentials["url"]+attachment_signed_url)
                 if att_response.status_code != 200:
                     raise ApiRequestFailure(Messages.get_message(message_id="failure_during_downloading_data_asset"), att_response)
 
@@ -616,12 +570,8 @@ class Assets(WMLResource):
         """
         Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
-        if not self._ICP and not self._client.WSD:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                      headers=self._client._get_headers(), verify=False)
+        response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+                                headers=self._client._get_headers())
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
         else:
@@ -631,12 +581,8 @@ class Assets(WMLResource):
     def _delete(self, asset_uid):
         Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
-        if not self._ICP and not self._client.WSD:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                       headers=self._client._get_headers())
-        else:
-            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
-                                       headers=self._client._get_headers(), verify=False)
+        response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+                                   headers=self._client._get_headers())
 
 
         # if response.status_code == 200:
@@ -682,7 +628,7 @@ class Assets(WMLResource):
     #                                 headers=self._client._get_headers())
     #     else:
     #         response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
-    #                                 headers=self._client._get_headers(), verify=False)
+    #                                 headers=self._client._get_headers())
     #     if response.status_code == 200:
     #         return response.json()["href"]
     #     else:
