@@ -48,8 +48,6 @@ from ibm_watson_machine_learning.import_assets import Import
 
 import copy
 import os
-import requests
-import sys
 
 
 '''
@@ -64,7 +62,7 @@ import sys
 class APIClient:
     version = None
 
-    def __init__(self, wml_credentials, project_id=None):
+    def __init__(self, wml_credentials, project_id=None, verify=None):
         self._logger = logging.getLogger(__name__)
         self.wml_credentials = copy.deepcopy(wml_credentials)
         self.CAMS = None
@@ -99,7 +97,19 @@ class APIClient:
             'https://us-south.ml.cloud.ibm.com': 'https://api.dataplatform.cloud.ibm.com'
         }
 
-        import requests
+        if verify:
+            os.environ['WML_CLIENT_VERIFY_REQUESTS'] = 'True'
+
+        elif isinstance(verify, str):
+            os.environ['WML_CLIENT_VERIFY_REQUESTS'] = verify
+
+        elif verify is None:
+            pass
+
+        else:
+            os.environ['WML_CLIENT_VERIFY_REQUESTS'] = 'False'
+
+        import ibm_watson_machine_learning._wrappers.requests as requests
         requests.packages.urllib3.disable_warnings()
 
         if "token" in wml_credentials:
