@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 
 from ibm_watson_machine_learning.messages.messages import Messages
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
@@ -105,11 +105,10 @@ class Connections(WMLResource):
         else:
             header_param = self._client._get_headers()
 
-        verify = not self._client.ICP_30 and not self._client.ICP and not self._client.WSD
         if connection_id:
             response = requests.get(self._client.service_instance._href_definitions.get_connection_by_id_href(connection_id),
                                     params=self._client._params(),
-                                    headers=header_param, verify=verify)
+                                    headers=header_param)
 
             if response.status_code == 200:
                 return self._get_required_element_from_response(
@@ -119,7 +118,7 @@ class Connections(WMLResource):
         else:
             response = requests.get(self._client.service_instance._href_definitions.get_connections_href(),
                                     params=self._client._params(),
-                                    headers=header_param, verify=verify)
+                                    headers=header_param)
 
             if response.status_code == 200:
                 return {'resources': [self._get_required_element_from_response(x) for x in response.json()['resources']]}
@@ -245,21 +244,12 @@ class Connections(WMLResource):
         else:
             header_param = self._client._get_headers()
 
-        if not self._client.ICP_30 and not self._client.ICP and not self._client.WSD:
-            creation_response = requests.post(
-                    self._client.service_instance._href_definitions.get_connections_href(),
-                    headers=header_param,
-                    params = self._client._params(),
-                    json=connection_meta
-            )
-        else:
-            creation_response = requests.post(
-                self._client.service_instance._href_definitions.get_connections_href(),
-                headers=header_param,
-                json=connection_meta,
-                params=self._client._params(),
-                verify=False
-            )
+        creation_response = requests.post(
+            self._client.service_instance._href_definitions.get_connections_href(),
+            headers=header_param,
+            json=connection_meta,
+            params=self._client._params()
+        )
         connection_details = self._handle_response(201, u'creating new connection', creation_response)
         if creation_response.status_code == 201:
             connection_id = connection_details["metadata"]["asset_id"]
@@ -301,12 +291,8 @@ class Connections(WMLResource):
             header_param = self._client._get_headers()
 
         connection_endpoint = self._client.service_instance._href_definitions.get_connection_by_id_href(connection_id)
-        if not self._ICP and not self._client.ICP_30 and not self._client.WSD:
-            response_delete = requests.delete(connection_endpoint, params=self._client._params(),
-                                              headers=header_param)
-        else:
-            response_delete = requests.delete(connection_endpoint, params=self._client._params(),
-                                              headers=header_param, verify=False)
+        response_delete = requests.delete(connection_endpoint, params=self._client._params(),
+                                          headers=header_param)
 
         return self._handle_response(204, u'connection deletion', response_delete, False)
 
@@ -362,12 +348,8 @@ class Connections(WMLResource):
         else:
             header_param = self._client._get_headers()
 
-        if not self._client.ICP_30 and not self._client.ICP and not self._client.WSD:
-            response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
-                                    headers=header_param)
-        else:
-            response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
-                                    headers=header_param, verify=False)
+        response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
+                                headers=header_param)
 
         datasource_details = self._handle_response(200, u'list datasource types', response)['resources']
         space_values = [
@@ -396,14 +378,9 @@ class Connections(WMLResource):
         else:
             header_param = self._client._get_headers()
 
-        if not self._client.ICP_30 and not self._client.ICP and not self._client.WSD:
-            response = requests.get(self._client.service_instance._href_definitions.get_connections_href(),
-                                    params=self._client._params(),
-                                    headers=header_param)
-        else:
-            response = requests.get(self._client.service_instance._href_definitions.get_connections_href(),
-                                    params=self._client._params(),
-                                    headers=header_param, verify=False)
+        response = requests.get(self._client.service_instance._href_definitions.get_connections_href(),
+                                params=self._client._params(),
+                                headers=header_param)
 
         self._handle_response(200, u'list datasource type', response)
 
@@ -474,12 +451,8 @@ class Connections(WMLResource):
         else:
             header_param = self._client._get_headers()
 
-        if not self._client.ICP_30 and not self._client.ICP and not self._client.WSD:
-            response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
-                                    headers=header_param)
-        else:
-            response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
-                                    headers=header_param, verify=False)
+        response = requests.get(self._client.service_instance._href_definitions.get_connection_data_types_href(),
+                                headers=header_param)
         datasource_id = 'None'
         datasource_details = self._handle_response(200, u'list datasource types', response)['resources']
         for i, ds_resource in enumerate(datasource_details):
