@@ -21,7 +21,7 @@ from warnings import warn
 from contextlib import redirect_stdout
 
 from pandas import DataFrame
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 
 from ..experiment import AutoAI
 from ..utils.autoai.utils import (prepare_auto_ai_model_to_publish, prepare_auto_ai_model_to_publish_normal_scenario,
@@ -609,8 +609,7 @@ class BaseDeployment(ABC):
         response = requests.post(
             promote_href,
             headers=self._source_workspace.wml_client._get_headers(),
-            json=promote_payload,
-            verify=False
+            json=promote_payload
         )
         promotion_details = self._source_workspace.wml_client.repository._handle_response(200, u'promote model asset',
                                                                                           response)
@@ -650,7 +649,7 @@ class BaseDeployment(ABC):
                 model=pipeline_model,
                 meta_props=meta_props)
 
-            project_asset_id = self._source_workspace.wml_client.repository.get_model_uid(published_model_details)
+            project_asset_id = self._source_workspace.wml_client.repository.get_model_id(published_model_details)
 
             asset_id = self._promote_model(model_id=project_asset_id,
                                            project_id=self._source_workspace.project_id,
@@ -661,7 +660,7 @@ class BaseDeployment(ABC):
                 model=pipeline_model,
                 meta_props=meta_props)
 
-            asset_id = self._target_workspace.wml_client.repository.get_model_uid(published_model_details)
+            asset_id = self._target_workspace.wml_client.repository.get_model_id(published_model_details)
 
         print(f"Published model uid: {asset_id}")
         return asset_id
