@@ -286,7 +286,8 @@ class Batch(BaseDeployment):
                 }
             )
 
-        job_details = self._target_workspace.wml_client.deployments.create_job(self.id, scoring_payload)
+        job_details = self._target_workspace.wml_client.deployments.create_job(self.id,
+                                                                               scoring_payload, _asset_id=self.asset_id)
 
         if background_mode:
             return job_details
