@@ -51,6 +51,11 @@ class AutoAI(BaseExperiment):
     space_id: str, optional
         ID of the Watson Studio Space.
 
+    verify: Union[bool, str], optional
+        User can pass verify the path to a CA_BUNDLE file or directory with certificates of trusted CAs.
+        If set to True, default path to truststore will be taken.
+        If set to False, no verification will be made.
+
     Example
     -------
     >>> from ibm_watson_machine_learning.experiment import AutoAI
@@ -85,7 +90,8 @@ class AutoAI(BaseExperiment):
     def __init__(self,
                  wml_credentials: Union[dict, 'WorkSpace'] = None,
                  project_id: str = None,
-                 space_id: str = None) -> None:
+                 space_id: str = None,
+                 verify=None) -> None:
         # note: as workspace is not clear enough to understand, there is a possibility to use pure
         # wml credentials with project and space IDs, but in addition we
         # leave a possibility to use a previous WorkSpace implementation, it could be passed as a first argument
@@ -99,7 +105,8 @@ class AutoAI(BaseExperiment):
             else:
                 self._workspace = WorkSpace(wml_credentials=wml_credentials.copy(),
                                             project_id=project_id,
-                                            space_id=space_id)
+                                            space_id=space_id,
+                                            verify=verify)
 
             self.project_id = self._workspace.project_id
             self.space_id = self._workspace.space_id
