@@ -87,7 +87,7 @@ class WMLEngine(BaseEngine):
                     'id': 'autoai',
                     'runtime_ref': 'hybrid',
                     'nodes': [{
-                        'id': 'automl',
+                        'id': 'autoai-ts' if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING else 'automl',
                         'type': 'execution_node',
                         'parameters': {
                             'stage_flag': True,
@@ -126,8 +126,10 @@ class WMLEngine(BaseEngine):
                 'pipelines'][0]['nodes'][0]['parameters']['enable_all_data_sources'
             ] = kwargs['enable_all_data_sources']
 
-        # Text transformer params
-        if not self._wml_client.ICP_30 and not self._wml_client.ICP_35:
+        # New parameters for autoai-core which are not supported in CP4D 3.0 and CPD 3.5
+        if not self._wml_client.ICP_30 and not self._wml_client.ICP_35 and \
+                self._auto_pipelines_parameters.get('prediction_type') != PredictionType.FORECASTING:
+            # Text transformer params
             if self._auto_pipelines_parameters.get('text_processing') is not None:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
@@ -142,7 +144,11 @@ class WMLEngine(BaseEngine):
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'text_columns'] = self._auto_pipelines_parameters.get('text_columns_names')
-
+                # end of Text transformer parameters
+                if self._auto_pipelines_parameters.get('retrain_on_holdout'):
+                    self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                        'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                        'retrain_on_holdout'] = self._auto_pipelines_parameters.get('retrain_on_holdout')
         # end of section
 
         # pass fairness info if not CPD
@@ -223,10 +229,6 @@ class WMLEngine(BaseEngine):
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'scorer_for_ranking'] = self._auto_pipelines_parameters.get('scoring')
-            if 'retrain_on_holdout' in self._auto_pipelines_parameters:
-                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
-                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
-                    'retrain_on_holdout'] = self._auto_pipelines_parameters.get('retrain_on_holdout')
 
         if self._20_class_limit_removal_test:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT]['pipelines'][0]['nodes'][0]['parameters'].update({
@@ -960,7 +962,6 @@ class WMLEngine(BaseEngine):
         -------
         Scikit-Learn pipeline.
         """
-        try_import_autoai_libs()
 
         # note: Show warning if OBM
         if 'auto_ai.obm' in str(self._wml_stored_pipeline_details):
@@ -978,6 +979,8 @@ class WMLEngine(BaseEngine):
 
         if 'timeseries' in run_params['entity']['status']['metrics'][0]['context']:
             try_import_autoai_ts_libs()
+        else:
+            try_import_autoai_libs()
 
         try:
             pipelines, check_lale = fetch_pipelines(
