@@ -156,7 +156,8 @@ class LocalAutoPipelinesRuns(BaseAutoPipelinesRuns):
             # note: cloud auto-gen notebook scenario
             else:
                 # note: save training connection to be able to further provide this data via get_data_connections
-                self.training_data_reference: List['DataConnection'] = metadata.get('training_data_reference')
+                self.training_data_reference: List['DataConnection'] = metadata.get('training_data_references',
+                                                                                    metadata.get('training_data_reference'))
                 self.training_result_reference: 'DataConnection' = training_result_reference
 
                 # note: fill experiment parameters to be able to recreate holdout split
