@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import json
 import re
 import time
@@ -136,15 +136,13 @@ class Experiments(WMLResource):
                     self._client.service_instance._href_definitions.get_experiments_href(),
                     json=metaProps,
                     params=self._client._params(skip_for_create=True),
-                    headers=self._client._get_headers(),
-                    verify=False
+                    headers=self._client._get_headers()
                 )
             else:
                 response_experiment_post = requests.post(
                     self._client.service_instance._href_definitions.get_experiments_href(),
                     json=metaProps,
-                    headers=self._client._get_headers(),
-                    verify=False
+                    headers=self._client._get_headers()
                 )
 
         return self._handle_response(201, u'saving experiment', response_experiment_post)
@@ -191,10 +189,7 @@ class Experiments(WMLResource):
         patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details['entity'], changes, with_validation=True)
 
         url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
-        if not self._ICP:
-            response = requests.patch(url, json=patch_payload, params = self._client._params(),headers=self._client._get_headers())
-        else:
-            response = requests.patch(url, json=patch_payload, params = self._client._params(),headers=self._client._get_headers(), verify=False)
+        response = requests.patch(url, json=patch_payload, params = self._client._params(),headers=self._client._get_headers())
         updated_details = self._handle_response(200, u'experiment patch', response)
 
         return updated_details
@@ -385,10 +380,7 @@ class Experiments(WMLResource):
         Experiments._validate_type(experiment_uid, u'experiment_uid', STR_TYPE, True)
 
         url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
-        if not self._ICP:
-            response = requests.delete(url, params = self._client._params(),headers=self._client._get_headers())
-        else:
-            response = requests.delete(url, params = self._client._params(),headers=self._client._get_headers(), verify=False)
+        response = requests.delete(url, params = self._client._params(),headers=self._client._get_headers())
 
         return self._handle_response(204, u'experiment deletion', response, False)
 
@@ -574,12 +566,8 @@ class Experiments(WMLResource):
             clone_meta["rev"] = rev
 
         url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
-        if not self._ICP:
-            response_post = requests.post(url, json=clone_meta,
-                                          headers=self._client._get_headers())
-        else:
-            response_post = requests.post(url, json=clone_meta,
-                                          headers=self._client._get_headers(), verify=False)
+        response_post = requests.post(url, json=clone_meta,
+                                      headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=200, operationName=u'cloning experiment',
                                         response=response_post)
