@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import INSTANCE_DETAILS_TYPE, FUNCTION_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, str_type_conv, is_of_python_basic_type, meta_props_str_conv
 from ibm_watson_machine_learning.metanames import FunctionMetaNames, FunctionNewMetaNames
 import os
@@ -248,10 +248,7 @@ score = {}()
                         # runtime_uid = self._client.runtimes.get_uid(runtime_details)
                         # set the default to 3.6 runtime as 3.5 is no longer supported.
                         runtime_uid="ai-function_0.1-py3.6"
-                        if not self._ICP:
-                            check_runtime = requests.get(self._client.service_instance._href_definitions.get_runtime_href(runtime_uid),  headers=self._client._get_headers())
-                        else:
-                            check_runtime = requests.get(self._client.service_instance._href_definitions.get_runtime_href(runtime_uid),  headers=self._client._get_headers(),verify=False)
+                        check_runtime = requests.get(self._client.service_instance._href_definitions.get_runtime_href(runtime_uid),  headers=self._client._get_headers())
 
                         if check_runtime.status_code != 200:
                             print('No matching default runtime found. Creating one...', end="")
@@ -310,28 +307,15 @@ score = {}()
                             "It is mandatory to set the space/project id. Use client.set.default_space(<SPACE_UID>)/"
                             "client.set.default_project(<PROJECT_UID>) to proceed.")
 
-                if not self._ICP:
-                    if self._client.CLOUD_PLATFORM_SPACES:
-                        response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
-                                                      json=function_metadata,
-                                                      params=self._client._params(skip_for_create=True),
-                                                      headers=self._client._get_headers())
-                    else:
-                        response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
-                                                      json=function_metadata,
-                                                      headers=self._client._get_headers())
+                if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
+                    response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
+                                                  json=function_metadata,
+                                                  params=self._client._params(skip_for_create=True),
+                                                  headers=self._client._get_headers())
                 else:
-                    if self._client.ICP_PLATFORM_SPACES:
-                        response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
-                                                      json=function_metadata,
-                                                      params=self._client._params(skip_for_create=True),
-                                                      headers=self._client._get_headers(),
-                                                      verify=False)
-                    else:
-                        response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
-                                                      json=function_metadata,
-                                                      headers=self._client._get_headers(),
-                                                      verify=False)
+                    response_post = requests.post(self._client.service_instance._href_definitions.get_functions_href(),
+                                                  json=function_metadata,
+                                                  headers=self._client._get_headers())
 
                 details = self._handle_response(expected_status_code=201,
                                                 operationName=u'saving function',
@@ -346,17 +330,10 @@ score = {}()
 
                 put_header = self._client._get_headers(no_content_type=True)
                 with open(content_path, 'rb') as data:
-                    if not self._ICP:
-                        response_definition_put = requests.put(function_content_url,
-                                                               data=data,
-                                                               params=self._client._params(),
-                                                               headers=put_header)
-                    else:
-                        response_definition_put = requests.put(function_content_url,
-                                                               data=data,
-                                                               params = self._client._params(),
-                                                               headers=put_header,
-                                                               verify=False)
+                    response_definition_put = requests.put(function_content_url,
+                                                           data=data,
+                                                           params=self._client._params(),
+                                                           headers=put_header)
 
         except Exception as e:
             raise e
@@ -419,10 +396,7 @@ score = {}()
 
         url = self._client.service_instance._href_definitions.get_function_href(function_uid)
         headers = self._client._get_headers()
-        if not self._ICP:
-            response = requests.patch(url, json=patch_payload, params = self._client._params(),headers=headers)
-        else:
-            response = requests.patch(url, json=patch_payload,params = self._client._params(), headers=headers, verify=False)
+        response = requests.patch(url, json=patch_payload, params = self._client._params(),headers=headers)
         updated_details = self._handle_response(200, u'function patch', response)
 
         if (self._client.ICP_30 or self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES) and update_function is not None:
@@ -519,13 +493,8 @@ score = {}()
 
             put_header = self._client._get_headers(no_content_type=True)
             with open(content_path, 'rb') as data:
-                if not self._ICP:
-                    response_definition_put = requests.put(function_content_url, data=data,
-                                                           params=self._client._params(), headers=put_header)
-                else:
-                    response_definition_put = requests.put(function_content_url, data=data,
-                                                           params=self._client._params(), headers=put_header,
-                                                           verify=False)
+                response_definition_put = requests.put(function_content_url, data=data,
+                                                       params=self._client._params(), headers=put_header)
                 if response_definition_put.status_code != 200 and response_definition_put.status_code != 204 and response_definition_put.status_code != 201:
                     raise WMLClientError(" Unable to update function content" + response_definition_put)
         except Exception as e:
@@ -620,8 +589,7 @@ score = {}()
                 r = requests.get(artifact_content_url,
                                  params=params,
                                  headers=self._client._get_headers(),
-                                 stream=True,
-                                 verify=False)
+                                 stream=True)
             if r.status_code != 200:
                 raise ApiRequestFailure(u'Failure during {}.'.format("downloading function"), r)
 
@@ -691,7 +659,7 @@ score = {}()
             if not self._client.WSD and Functions._if_deployment_exist_for_asset(self, function_uid):
                 raise WMLClientError(
                     u'Cannot delete function that has existing deployments. Please delete all associated deployments and try again')
-            response_delete = requests.delete(function_endpoint, params = self._client._params(), headers=self._client._get_headers(), verify=False)
+            response_delete = requests.delete(function_endpoint, params = self._client._params(), headers=self._client._get_headers())
         return self._handle_response(204, u'function deletion', response_delete, False)
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -724,7 +692,7 @@ score = {}()
                     u'Cannot delete function that has existing deployments. Please delete all associated deployments and try again')
 
             response_delete = requests.delete(function_endpoint, params=self._client._params(),
-                                              headers=self._client._get_headers(), verify=False)
+                                              headers=self._client._get_headers())
         response_delete
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -988,12 +956,8 @@ score = {}()
             clone_meta["rev"] = rev
 
         url = self._client.service_instance._href_definitions.get_function_href(function_uid)
-        if not self._ICP:
-            response_post = requests.post(url, json=clone_meta,
-                                              headers=self._client._get_headers())
-        else:
-            response_post = requests.post(url, json=clone_meta,
-                                              headers=self._client._get_headers(), verify=False)
+        response_post = requests.post(url, json=clone_meta,
+                                          headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=200, operationName=u'cloning function',
                                             response=response_post)
