@@ -24,7 +24,7 @@ from abc import ABC, abstractmethod
 from typing import Union, Tuple, TYPE_CHECKING
 from warnings import warn
 
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from pandas import concat, DataFrame, read_csv
 
 from ibm_watson_machine_learning.utils.autoai.utils import try_load_dataset, try_load_tar_gz
@@ -156,7 +156,7 @@ class BaseDataConnection(ABC):
             json_url = self._wml_client.service_instance._href_definitions.get_wsd_model_attachment_href() + f"/auto_ml/{path.split('/auto_ml/')[-1]}"
 
             with requests.get(json_url, params=self._wml_client._params(), headers=self._wml_client._get_headers(),
-                              stream=True, verify=False) as file_response:
+                              stream=True) as file_response:
                 if file_response.status_code != 200:
                     raise ApiRequestFailure(u'Failure during {}.'.format("downloading json"), file_response)
 
@@ -202,17 +202,10 @@ class BaseDataConnection(ABC):
                     data_asset_details = self._wml_client.data_assets.get_details(_id)
 
                     attachment_id = data_asset_details['metadata']['attachment_id']
-                    if not self._wml_client.ICP and not self._wml_client.WSD:
-                        response = requests.get(
-                            self._wml_client.service_instance._href_definitions.get_attachment_href(_id, attachment_id),
-                            params=self._wml_client.data_assets._client._params(),
-                            headers=self._wml_client.data_assets._client._get_headers())
-                    else:
-                        response = requests.get(
-                            self._wml_client.service_instance._href_definitions.get_attachment_href(_id, attachment_id),
-                            params=self._wml_client.data_assets._client._params(),
-                            headers=self._wml_client.data_assets._client._get_headers(),
-                            verify=False)
+                    response = requests.get(
+                        self._wml_client.service_instance._href_definitions.get_attachment_href(_id, attachment_id),
+                        params=self._wml_client.data_assets._client._params(),
+                        headers=self._wml_client.data_assets._client._get_headers())
 
                     if response.status_code == 200:
                         attachment_details = response.json()
@@ -423,30 +416,24 @@ class BaseDataConnection(ABC):
             asset_response = requests.get(
                 self._wml_client.service_instance._href_definitions.get_data_asset_href(asset_id),
                 params=self._wml_client._params(),
-                headers=self._wml_client._get_headers(),
-                verify=False)
+                headers=self._wml_client._get_headers())
 
             asset_details = self._wml_client.data_assets._handle_response(200, u'get assets', asset_response)
 
             attachment_id = asset_details['attachments'][0]['id']
-            if not self._wml_client.ICP and not self._wml_client.WSD:
-                response = requests.get(
-                    self._wml_client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id),
-                    params=self._wml_client.data_assets._client._params(),
-                    headers=self._wml_client.data_assets._client._get_headers())
-            else:
-                response = requests.get(
-                    self._wml_client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id),
-                    params=self._wml_client.data_assets._client._params(),
-                    headers=self._wml_client.data_assets._client._get_headers(),
-                    verify=False)
+            response = requests.get(
+                self._wml_client.service_instance._href_definitions.get_attachment_href(asset_id, attachment_id),
+                params=self._wml_client.data_assets._client._params(),
+                headers=self._wml_client.data_assets._client._get_headers())
 
             if response.status_code == 200:
                 try:
                     attachment_details = response.json()
                     if "url" in attachment_details:
                         file_asset_url = attachment_details['url']
-                        csv_response = requests.get(file_asset_url, verify=False)
+                        if not file_asset_url.startswith("http"):
+                            file_asset_url = self._wml_client.wml_credentials['url'] + file_asset_url
+                        csv_response = requests.get(file_asset_url)
 
                         if csv_response.status_code != 200:
                             raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
@@ -479,8 +466,7 @@ class BaseDataConnection(ABC):
                 csv_response = requests.get(artifact_content_url,
                                             params=self._wml_client._params(),
                                             headers=self._wml_client._get_headers(),
-                                            stream=True,
-                                            verify=False)
+                                            stream=True)
 
                 if csv_response.status_code != 200:
                     raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
@@ -541,8 +527,7 @@ class BaseDataConnection(ABC):
             csv_response = requests.get(url,
                                         params=self._wml_client._params(),
                                         headers=self._wml_client._get_headers(),
-                                        stream=True,
-                                        verify=False)
+                                        stream=True)
 
             if csv_response.status_code != 200:
                 raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
@@ -574,8 +559,7 @@ class BaseDataConnection(ABC):
             csv_response = requests.get(url,
                                         params=self._wml_client._params(),
                                         headers=self._wml_client._get_headers(),
-                                        stream=True,
-                                        verify=False)
+                                        stream=True)
 
             if csv_response.status_code != 200:
                 raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
@@ -607,8 +591,7 @@ class BaseDataConnection(ABC):
 
         response = requests.get(url,
                                 params=params,
-                                headers=self._wml_client._get_headers(),
-                                verify=False)
+                                headers=self._wml_client._get_headers())
 
         if response.status_code != 200:
             raise ApiRequestFailure(u'Failure during {}.'.format("getting files information"), response)
@@ -623,8 +606,7 @@ class BaseDataConnection(ABC):
             csv_response = requests.get(url + '/' + file_name,
                                         params=self._wml_client._params(),
                                         headers=self._wml_client._get_headers(),
-                                        stream=True,
-                                        verify=False)
+                                        stream=True)
 
             if csv_response.status_code != 200:
                 raise ApiRequestFailure(u'Failure during {}.'.format("downloading model"), csv_response)
@@ -664,7 +646,6 @@ class BaseDataConnection(ABC):
 
         csv_response = requests.get(full_href,
                                     headers=self._wml_client._get_headers(),
-                                    verify=False,
                                     stream=True)
 
         # Note: if file is written in directory we need to create different href for download
@@ -674,7 +655,6 @@ class BaseDataConnection(ABC):
 
             csv_response = requests.get(full_href,
                                         headers=self._wml_client._get_headers(),
-                                        verify=False,
                                         stream=True)
 
             if csv_response.status_code != 200:
@@ -699,18 +679,11 @@ class BaseDataConnection(ABC):
             else:
                 project_url = self._wml_client.service_instance._href_definitions.get_project_href(
                     self._wml_client.default_project_id)
-                if self._wml_client.ICP:
-                    response = requests.get(
-                        project_url,
-                        headers=self._wml_client._get_headers(),
-                        verify=False
-                    )
 
-                else:
-                    response = requests.get(
-                        project_url,
-                        headers=self._wml_client._get_headers()
-                    )
+                response = requests.get(
+                    project_url,
+                    headers=self._wml_client._get_headers()
+                )
 
                 details = response.json()
 
