@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,HW_SPEC_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import HwSpecMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -64,10 +64,10 @@ class HwSpec(WMLResource):
             if self._client.ICP_PLATFORM_SPACES:
                 response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid),
                                         params=self._client._params(skip_space_project_chk=True),
-                                        headers=self._client._get_headers(), verify=False)
+                                        headers=self._client._get_headers())
             else:
                 response = requests.get(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
-                                          headers=self._client._get_headers(), verify=False)
+                                          headers=self._client._get_headers())
 
         if response.status_code == 200:
             return self._get_required_element_from_response(self._handle_response(200, u'get hardware spec details', response))
@@ -119,7 +119,7 @@ class HwSpec(WMLResource):
     #     if not self._ICP:
     #         creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=hw_spec_meta_json)
     #     else:
-    #         creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=hw_spec_meta_json, verify=False)
+    #         creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=hw_spec_meta_json)
     #
     #     hw_spec_details = self._handle_response(201, u'creating new hw specs', creation_response)
     #
@@ -159,7 +159,7 @@ class HwSpec(WMLResource):
         if not self._ICP:
             response = requests.get(href, params, headers=self._client._get_headers())
         else:
-            response = requests.get(href, headers=self._client._get_headers(), verify=False)
+            response = requests.get(href, headers=self._client._get_headers())
         self._handle_response(200, u'list hw_specs', response)
         asset_details = self._handle_response(200, u'list assets', response)["resources"]
         hw_spec_values = [
@@ -318,7 +318,7 @@ class HwSpec(WMLResource):
         else:
             response = requests.get(self._client.service_instance._href_definitions.get_hw_specs_href(),
                                     params=parameters,
-                                    headers=self._client._get_headers(), verify=False)
+                                    headers=self._client._get_headers())
         if response.status_code == 200:
             total_values = self._handle_response(200, u'list assets', response)["total_results"]
             if total_values != 0:
@@ -355,7 +355,7 @@ class HwSpec(WMLResource):
     #                                 headers=self._client._get_headers())
     #     else:
     #         response = requests.delete(self._client.service_instance._href_definitions.get_hw_spec_href(hw_spec_uid), params=self._client._params(),
-    #                                   headers=self._client._get_headers(), verify=False)
+    #                                   headers=self._client._get_headers())
     #     if response.status_code == 200:
     #         return self._get_required_element_from_response(response.json())
     #     else:
