@@ -18,7 +18,7 @@ import os
 import sys
 import importlib.util
 
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import json
 import logging
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -35,7 +35,7 @@ def process_heartbeat(client, **kwargs):
         else:
             wml_services_url = agg_info['ip'].split('/')[0]
 
-        hearbeat_resp = requests.get("https://" + wml_services_url + "/wml_services/training/heartbeat", verify=False)
+        hearbeat_resp = requests.get("https://" + wml_services_url + "/wml_services/training/heartbeat")
         hearbeat_resp_json = json.loads(hearbeat_resp.content.decode("utf-8"))
         service_version = hearbeat_resp_json.get("service_implementation")
 
