@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import PIPELINE_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import PipelineMetanames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -266,8 +266,7 @@ class Pipelines(WMLResource):
                     atype_url,
                     params=self._client._params(),
                     data=atype_payload,
-                    headers=aheaders,
-                    verify=False
+                    headers=aheaders
                 )
 
                 if asset_type_response.status_code != 200 and \
@@ -278,8 +277,7 @@ class Pipelines(WMLResource):
                     pipeline_url,
                     params=self._client._params(),
                     headers=self._client._get_headers(),
-                    json=cams_payload,
-                    verify=False
+                    json=cams_payload
                 )
                 pipeline_details = self._handle_response(201, u'creating new pipeline', creation_response)
                 return WMLResource._wsd_get_required_element_from_response(self, pipeline_details)
@@ -289,15 +287,13 @@ class Pipelines(WMLResource):
                     self._client.service_instance._href_definitions.get_pipelines_href(),
                     headers=self._client._get_headers(),
                     params=self._client._params(skip_for_create=True),
-                    json=pipeline_meta,
-                    verify=False
+                    json=pipeline_meta
                  )
             else:
                 creation_response = requests.post(
                     self._wml_credentials['url'] + '/v4/pipelines',
                     headers=self._client._get_headers(),
-                    json=pipeline_meta,
-                    verify=False
+                    json=pipeline_meta
                 )
         pipeline_details = self._handle_response(201, u'creating new pipeline', creation_response)
 
@@ -378,7 +374,7 @@ class Pipelines(WMLResource):
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, params=self._client._params(),headers=self._client._get_headers())
         else:
-            response = requests.patch(url, json=patch_payload, params=self._client._params(),headers=self._client._get_headers(), verify=False)
+            response = requests.patch(url, json=patch_payload, params=self._client._params(),headers=self._client._get_headers())
 
         updated_details = self._handle_response(200, u'pipeline patch', response)
 
@@ -418,7 +414,7 @@ class Pipelines(WMLResource):
         if not self._ICP and not self._client.WSD:
             response_delete = requests.delete(pipeline_endpoint, params=self._client._params(),headers=self._client._get_headers())
         else:
-            response_delete = requests.delete(pipeline_endpoint, params=self._client._params(),headers=self._client._get_headers(), verify=False)
+            response_delete = requests.delete(pipeline_endpoint, params=self._client._params(),headers=self._client._get_headers())
 
         return self._handle_response(204, u'pipeline deletion', response_delete, False)
 
@@ -747,7 +743,7 @@ class Pipelines(WMLResource):
                                               headers=self._client._get_headers())
         else:
             response_post = requests.post(url, json=clone_meta,
-                                              headers=self._client._get_headers(), verify=False)
+                                              headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=200, operationName=u'cloning pipeline',
                                             response=response_post)
