@@ -13,7 +13,8 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests,json, time
+import ibm_watson_machine_learning._wrappers.requests as requests
+import json, time
 from ibm_watson_machine_learning.utils import SPACES_IMPORTS_DETAILS_TYPE, SPACES_EXPORTS_DETAILS_TYPE, SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos, print_text_header_h2
 from ibm_watson_machine_learning.utils import StatusLogger, print_text_header_h1, print_text_header_h2
 from ibm_watson_machine_learning.href_definitions import is_uid
@@ -45,19 +46,11 @@ class PlatformSpaces(WMLResource):
                 raise WMLClientError('Limit cannot be larger than 1000.')
 
         if len(params) > 0:
-            if not self._ICP:
-                response_get = requests.get(
-                    url,
-                    headers=self._client._get_headers(),
-                    params=params
-                )
-            else:
-                response_get = requests.get(
-                    url,
-                    headers=self._client._get_headers(),
-                    params=params,
-                    verify=False
-                )
+            response_get = requests.get(
+                url,
+                headers=self._client._get_headers(),
+                params=params
+            )
 
             return self._handle_response(200, op_name, response_get)
         else:
@@ -68,7 +61,7 @@ class PlatformSpaces(WMLResource):
                 if not self._ICP:
                     response_get = requests.get( url, headers=self._client._get_headers())
                 else:
-                    response_get = requests.get( url, headers=self._client._get_headers(), verify=False)
+                    response_get = requests.get( url, headers=self._client._get_headers())
 
                 result = self._handle_response(200, op_name, response_get)
                 resources.extend(result['resources'])
@@ -151,17 +144,10 @@ class PlatformSpaces(WMLResource):
             payload_compute.append(space_meta[u'compute'])
             space_meta[u'compute'] = payload_compute
 
-        if not self._ICP:
-            creation_response = requests.post(
-                self._client.service_instance._href_definitions.get_platform_spaces_href(),
-                headers=self._client._get_headers(),
-                json=space_meta)
-        else:
-            creation_response = requests.post(
-                self._client.service_instance._href_definitions.get_platform_spaces_href(),
-                headers=self._client._get_headers(),
-                json=space_meta,
-                verify=False)
+        creation_response = requests.post(
+            self._client.service_instance._href_definitions.get_platform_spaces_href(),
+            headers=self._client._get_headers(),
+            json=space_meta)
 
         spaces_details = self._handle_response(202, u'creating new spaces', creation_response)
 
@@ -286,7 +272,7 @@ class PlatformSpaces(WMLResource):
 
             **Example**
 
-             >>> client.spaces.delete(deployment_id)
+             >>> client.spaces.delete(space_id)
         """
 
         space_id = str_type_conv(space_id)
@@ -297,7 +283,7 @@ class PlatformSpaces(WMLResource):
         if not self._ICP:
             response_delete = requests.delete(space_endpoint, headers=self._client._get_headers())
         else:
-            response_delete = requests.delete(space_endpoint, headers=self._client._get_headers(), verify=False)
+            response_delete = requests.delete(space_endpoint, headers=self._client._get_headers())
 
         response = self._handle_response(202, u'space deletion', response_delete, False)
 
@@ -348,7 +334,7 @@ class PlatformSpaces(WMLResource):
             if not self._ICP:
                 response_get = requests.get(href, headers=self._client._get_headers())
             else:
-                response_get = requests.get(href, headers=self._client._get_headers(), verify=False)
+                response_get = requests.get(href, headers=self._client._get_headers())
 
             return self._handle_response(200, 'Get space', response_get)
 
@@ -422,8 +408,8 @@ class PlatformSpaces(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def update(self, space_id, changes):
         """
-                Updates existing space metadata. 'STORAGE' cannot be updated
-                STORAGE and COMPUTE are applicable only for cloud
+                Updates existing space metadata. 'STORAGE' cannot be updated.
+                STORAGE and COMPUTE are applicable only for cloud.
 
                 **Parameters**
 
@@ -483,7 +469,7 @@ class PlatformSpaces(WMLResource):
         if not self._ICP:
             response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
         else:
-            response = requests.patch(href, json=patch_payload, headers=self._client._get_headers(), verify=False)
+            response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
 
         updated_details = self._handle_response(200, u'spaces patch', response)
 
@@ -558,17 +544,10 @@ class PlatformSpaces(WMLResource):
             client=self._client
         )
 
-        if not self._ICP:
-            creation_response = requests.post(
-                self._client.service_instance._href_definitions.get_platform_spaces_members_href(space_id),
-                headers=self._client._get_headers(),
-                json=space_meta)
-        else:
-            creation_response = requests.post(
-                self._client.service_instance._href_definitions.get_platform_spaces_members_href(space_id),
-                headers=self._client._get_headers(),
-                json=space_meta,
-                verify=False)
+        creation_response = requests.post(
+            self._client.service_instance._href_definitions.get_platform_spaces_members_href(space_id),
+            headers=self._client._get_headers(),
+            json=space_meta)
 
         # TODO: Change response code one they change it to 201
         members_details = self._handle_response(200, u'creating new members', creation_response)
@@ -608,7 +587,7 @@ class PlatformSpaces(WMLResource):
         if not self._ICP:
             response_get = requests.get(href, headers=self._client._get_headers())
         else:
-            response_get = requests.get(href, headers=self._client._get_headers(), verify=False)
+            response_get = requests.get(href, headers=self._client._get_headers())
 
         return self._handle_response(200, 'Get space member', response_get)
 
@@ -647,7 +626,7 @@ class PlatformSpaces(WMLResource):
         if not self._ICP:
             response_delete = requests.delete(member_endpoint, headers=self._client._get_headers())
         else:
-            response_delete = requests.delete(member_endpoint, headers=self._client._get_headers(), verify=False)
+            response_delete = requests.delete(member_endpoint, headers=self._client._get_headers())
 
         print('DELETED')
 
@@ -742,7 +721,7 @@ class PlatformSpaces(WMLResource):
             if not self._ICP:
                 response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
             else:
-                response = requests.patch(href, json=patch_payload, headers=self._client._get_headers(), verify=False)
+                response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
 
             updated_details = self._handle_response(200, u'members patch', response)
 
