@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import get_url, INSTANCE_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, str_type_conv, is_python_2
 from ibm_watson_machine_learning.metanames import ModelMetaNames, ExperimentMetaNames, FunctionMetaNames, PipelineMetanames, SpacesMetaNames, MemberMetaNames, FunctionNewMetaNames
 from ibm_watson_machine_learning.wml_client_error import WMLClientError
@@ -27,6 +27,7 @@ from multiprocessing import Pool
 from ibm_watson_machine_learning.libs.repo.mlrepositoryclient import MLRepositoryClient
 from ibm_watson_machine_learning.href_definitions import API_VERSION, SPACES,PIPELINES, LIBRARIES, EXPERIMENTS, RUNTIMES, DEPLOYMENTS
 import os
+from warnings import warn
 _DEFAULT_LIST_LENGTH = 50
 
 
@@ -497,7 +498,7 @@ class Repository(WMLResource):
                                           headers=self._client._get_headers())
         else:
             response_post = requests.post(url, json=clone_meta,
-                                          headers=self._client._get_headers(), verify=False)
+                                          headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=200, operationName=u'cloning '+ type,
                                         response=response_post)
@@ -951,7 +952,7 @@ class Repository(WMLResource):
         else:
             response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(artifact_uid),
                                        params=params,
-                                       headers=self._client._get_headers(), verify=False)
+                                       headers=self._client._get_headers())
 
         if response.status_code == 200 or response.status_code == 204:
             if response.status_code == 200:
@@ -1452,25 +1453,10 @@ class Repository(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_model_uid(model_details):
         """
-            Get Unique Id of stored model.
-
-           **Parameters**
-
-           .. important::
-                #. **model_details**:  Metadata of the stored model\n
-                   **type**: dict\n
-
-           **Output**
-
-           .. important::
-                **returns**: Unique Id of stored model\n
-                **return type**: str\n
-
-           **Example**
-
-            >>> model_details = client.repository.get_model_details(model_uid)
-            >>> model_uid = client.repository.get_model_uid(model_details)
+            This method is deprecated, please use get_id() instead."
         """
+        warn("This method is deprecated, please use get_model_id()")
+        print("This method is deprecated, please use get_model_id()")
 
         return Models.get_id(model_details)
 
@@ -1494,8 +1480,7 @@ class Repository(WMLResource):
 
            **Example**
 
-            >>> model_details = client.repository.get_model_details(model_uid)
-            >>> model_uid = client.repository.get_model_id(model_details)
+            >>> model_id = client.repository.get_model_id(model_details)
         """
 
         return Models.get_id(model_details)
@@ -2145,8 +2130,7 @@ class Repository(WMLResource):
             endpoint = self._client.service_instance._href_definitions.get_model_definition_assets_href() + "/" + artifact_uid
             response = requests.get(
                 endpoint,
-                params=self._client._params(),
-                verify=False
+                params=self._client._params()
             )
 
            # requestsget_url, (endpoint, self._client._get_headers(), self._client._params(), True))
