@@ -13,7 +13,8 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests,json
+import ibm_watson_machine_learning._wrappers.requests as requests
+import json
 from ibm_watson_machine_learning.utils import SPACES_IMPORTS_DETAILS_TYPE, SPACES_EXPORTS_DETAILS_TYPE, SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos, print_text_header_h2
 from ibm_watson_machine_learning.metanames import SpacesMetaNames, MemberMetaNames, ExportMetaNames
 from ibm_watson_machine_learning.href_definitions import is_uid
@@ -80,21 +81,11 @@ class Spaces(WMLResource):
 
         )
 
-
-        if not self._ICP:
-            creation_response = requests.post(
-                    self._wml_credentials['url'] + '/v4/spaces',
-                    headers=self._client._get_headers(),
-                    json=space_meta
-            )
-        else:
-            creation_response = requests.post(
-                self._wml_credentials['url'] + '/v4/spaces',
-                headers=self._client._get_headers(),
-                json=space_meta,
-                verify=False
-            )
-
+        creation_response = requests.post(
+            self._wml_credentials['url'] + '/v4/spaces',
+            headers=self._client._get_headers(),
+            json=space_meta
+        )
 
         spaces_details = self._handle_response(201, u'creating new spaces', creation_response)
 
@@ -192,7 +183,7 @@ class Spaces(WMLResource):
         if not self._ICP:
             response_delete = requests.delete(space_endpoint, headers=self._client._get_headers())
         else:
-            response_delete = requests.delete(space_endpoint, headers=self._client._get_headers(), verify=False)
+            response_delete = requests.delete(space_endpoint, headers=self._client._get_headers())
 
         return self._handle_response(204, u'space deletion', response_delete, False)
 
@@ -301,7 +292,7 @@ class Spaces(WMLResource):
         if not self._ICP:
             response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
         else:
-            response = requests.patch(href, json=patch_payload, headers=self._client._get_headers(), verify=False)
+            response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
         updated_details = self._handle_response(200, u'spaces patch', response)
 
         return updated_details
@@ -386,7 +377,7 @@ class Spaces(WMLResource):
         if not self._ICP:
             response_delete = requests.delete(member_endpoint, headers=self._client._get_headers())
         else:
-            response_delete = requests.delete(member_endpoint, headers=self._client._get_headers(), verify=False)
+            response_delete = requests.delete(member_endpoint, headers=self._client._get_headers())
 
         return self._handle_response(204, u'space member deletion', response_delete, False)
 
@@ -438,7 +429,7 @@ class Spaces(WMLResource):
             if not self._ICP:
                 response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
             else:
-                response = requests.patch(href, json=patch_payload, headers=self._client._get_headers(), verify=False)
+                response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
             updated_details = self._handle_response(200, u'members patch', response)
 
             return updated_details
@@ -489,21 +480,11 @@ class Spaces(WMLResource):
 
         )
 
-
-        if not self._ICP:
-            creation_response = requests.post(
-                    self._wml_credentials['url'] + '/v4/spaces/'+space_uid+"/members",
-                    headers=self._client._get_headers(),
-                    json=space_meta
-            )
-        else:
-            creation_response = requests.post(
-                self._wml_credentials['url'] + '/v4/spaces/'+space_uid+"/members",
-                headers=self._client._get_headers(),
-                json=space_meta,
-                verify=False
-            )
-
+        creation_response = requests.post(
+            self._wml_credentials['url'] + '/v4/spaces/'+space_uid+"/members",
+            headers=self._client._get_headers(),
+            json=space_meta
+        )
 
         members_details = self._handle_response(201, u'creating new members', creation_response)
 
@@ -602,7 +583,7 @@ class Spaces(WMLResource):
     def imports(self, space_uid, file_path):
         """
                 Updates existing space metadata.
-                Imports assets in the zip file to a space
+                Imports assets in the zip file to a space.
 
                 **Parameters**
 
@@ -638,7 +619,7 @@ class Spaces(WMLResource):
         if not self._ICP:
             response = requests.post(href, headers=self._client._get_headers(), data=data)
         else:
-            response = requests.post(href, headers=self._client._get_headers(), data=data, verify=False)
+            response = requests.post(href, headers=self._client._get_headers(), data=data)
         import_space_details = self._handle_response(202, u'spaces import', response)
 
         return import_space_details
@@ -745,7 +726,7 @@ class Spaces(WMLResource):
         if not self._ICP:
             response = requests.get(href, headers=self._client._get_headers())
         else:
-            response = requests.get(href, headers=self._client._get_headers(), verify=False)
+            response = requests.get(href, headers=self._client._get_headers())
         import_space_details = self._handle_response(200, u'spaces import details', response)
 
         return import_space_details
@@ -754,7 +735,7 @@ class Spaces(WMLResource):
     def exports(self, space_uid, meta_props):
         """
                 Updates existing space metadata.
-                exports assets in the zip file from a space
+                Exports assets in the zip file from a space.
 
                 **Parameters**
 
@@ -796,7 +777,7 @@ class Spaces(WMLResource):
         if not self._ICP:
             response = requests.post(href, headers=self._client._get_headers(), data=space_exports_meta_json)
         else:
-            response = requests.post(href, headers=self._client._get_headers(), data=space_exports_meta_json, verify=False)
+            response = requests.post(href, headers=self._client._get_headers(), data=space_exports_meta_json)
         export_space_details = self._handle_response(202, u'spaces export', response)
 
         return export_space_details
@@ -845,7 +826,7 @@ class Spaces(WMLResource):
         if not self._ICP:
             response = requests.get(href, headers=self._client._get_headers())
         else:
-            response = requests.get(href, headers=self._client._get_headers(), verify=False)
+            response = requests.get(href, headers=self._client._get_headers())
         export_space_details = self._handle_response(200, u'spaces exports details', response)
 
         return export_space_details
@@ -885,17 +866,11 @@ class Spaces(WMLResource):
 
         href =  self._client.service_instance._href_definitions.get_space_href(space_uid) + "/exports/" + space_exports_uid + "/content"
 
-        if not self._ICP:
-            response = requests.get(
-                href,
-                headers=self._client._get_headers()
-            )
-        else:
-            response = requests.get(
-                href,
-                headers=self._client._get_headers(),
-                verify=False
-            )
+        response = requests.get(
+            href,
+            headers=self._client._get_headers()
+        )
+
         if filename is None:
             filename = 'wmlspace.zip'
 
