@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import json
 import re
 import logging
@@ -204,8 +204,13 @@ class Training(WMLResource):
         """
         warn("This method is deprecated, please use get_id()")
         print("This method is deprecated, please use get_id()")
-        Training._validate_type(training_details, u'training_details', object, True)
-        return WMLResource._get_required_element_from_dict(training_details, u'training_details', [u'metadata', u'guid'])
+
+        try:
+            Training._validate_type(training_details, u'training_details', object, True)
+            return WMLResource._get_required_element_from_dict(training_details, u'training_details',
+                                                               [u'metadata', u'guid'])
+        except Exception:
+            return Training.get_id(training_details)
 
     @staticmethod
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -347,7 +352,7 @@ class Training(WMLResource):
          >>> client.training.ConfigurationMetaNames.PIPELINE_UID : "/v4/pipelines/<PIPELINE-ID>"
          >>> }
          >>> training_details = client.training.run(definition_uid, meta_props=metadata)
-         >>> training_uid = client.training.get_uid(training_details)
+         >>> training_uid = client.training.get_id(training_details)
         """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -482,15 +487,14 @@ class Training(WMLResource):
                 response_train_post = requests.post(train_endpoint,
                                                     json=training_configuration_metadata,
                                                     params=params,
-                                                    headers=self._client._get_headers(),
-                                                    verify=False)
+                                                    headers=self._client._get_headers())
 
             elif self._client.ICP_30:
                 response_train_post = requests.post(train_endpoint, json=training_configuration_metadata,
-                                                    headers=self._client._get_headers(),verify=False)
+                                                    headers=self._client._get_headers())
             else:
                 response_train_post = requests.post(train_endpoint, json=training_configuration_metadata,
-                                                    headers=self._client._get_headers(), verify=False)
+                                                    headers=self._client._get_headers())
 
         run_details = self._handle_response(201, u'training', response_train_post)
 
@@ -596,16 +600,12 @@ class Training(WMLResource):
 
         self._client._check_if_either_is_set()
         details = self.get_details(training_uid)
-        verify=True
-        if self._client.ICP:
-            verify=False
         if "experiment" not in details["entity"]:
             raise WMLClientError("Sub-trainings are available for training created via experiment only.")
         details_parent = requests.get(
             self._wml_credentials['url'] + '/v4/trainings?parent_id=' + training_uid,
             params=self._client._params(),
-            headers=self._client._get_headers(),
-            verify=verify
+            headers=self._client._get_headers()
         )
         details_json = self._handle_response(200, "Get training details", details_parent)
         resources = details_json["resources"]
@@ -738,7 +738,7 @@ class Training(WMLResource):
                                           headers=self._client._get_headers(),params=params)
         else:
             response_delete = requests.delete(self._client.service_instance._href_definitions.get_training_href(training_uid),
-                                              headers=self._client._get_headers(),params=params,verify=False)
+                                              headers=self._client._get_headers(),params=params)
 
         if response_delete.status_code == 400 and \
            response_delete.text is not None and 'Job already completed with state' in response_delete.text:
