@@ -70,7 +70,7 @@ import logging
 from collections.abc import Sequence
 
 import pkg_resources
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from packaging import version
 
 from .enums import (RegressionAlgorithms, RegressionAlgorithmsCP4D, ClassificationAlgorithms,
@@ -335,8 +335,7 @@ def load_file_from_file_system(wml_client: 'APIClient',
     response_with_model = requests.get(
         url=f"{wml_client.service_instance._href_definitions.get_wsd_model_attachment_href()}auto_ml/{file_path}",
         headers=wml_client._get_headers(),
-        stream=stream,
-        verify=False)
+        stream=stream)
     if stream:
         for data in response_with_model.iter_content():
             buffer.write(data)
@@ -378,8 +377,7 @@ def load_file_from_file_system_nonautoai(wml_client: 'APIClient',
         url=f"{wml_client.service_instance._href_definitions.get_wsd_model_attachment_href()}{file_path}",
         headers=wml_client._get_headers(),
         params=wml_client._params(),
-        stream=stream,
-        verify=False)
+        stream=stream)
 
     if stream:
         for data in response_with_model.iter_content():
@@ -413,8 +411,7 @@ class NextRunDetailsGenerator:
         if self.next_href is not None:
             response = requests.get(
                 url=f"{self.wml_client.wml_credentials['url']}{self.next_href}",
-                headers=self.wml_client._get_headers(),
-                verify=not self.wml_client.ICP)
+                headers=self.wml_client._get_headers())
             details = response.json()
             self.next_href = details.get('next', {'href': None})['href']
             return details.get('resources', [])
@@ -505,7 +502,8 @@ def prepare_auto_ai_model_to_publish_notebook_normal_scenario(
     path = result_connection.location._model_location
     model_number = pipeline_model.split('_')[-1]
     run_id = path.split('/data/')[0].split('/')[-1]
-    request_path = f"{path.split('/data/')[0]}/assets/{run_id}_P{model_number}_{chose_model_output(model_number)}/resources/wml_model/request.json"
+    is_ts_metrics = 'autoai-ts' in path
+    request_path = f"{path.split('/data/')[0]}/assets/{run_id}_P{model_number}_{chose_model_output(model_number, is_ts_metrics=is_ts_metrics)}/resources/wml_model/request.json"
 
     bucket = result_connection.location.bucket
     cos_client.meta.client.download_file(Bucket=bucket, Filename='request.json', Key=request_path)
@@ -951,7 +949,7 @@ def try_import_autoai_libs(minimum_version: str = None):
     Check if autoai_libs package is installed in local environment, if not, just download and install it.
     """
     package = {'name': 'autoai-libs'}
-    default_version = '1.12.14'
+    default_version = '1.13.0'
 
     if minimum_version is not None:
         default_version = minimum_version
@@ -1556,15 +1554,21 @@ def download_experiment_details_from_file(result_client_and_connection: Tuple['D
 
 def download_wml_pipeline_details_from_file(result_client_and_connection: Tuple['DataConnection', 'resource']) -> dict:
     """Try to download wml pipeline details from user COS."""
-
     try:
-        path_parts = result_client_and_connection[0].location._model_location.split('model.pickle')
+        model_location = result_client_and_connection[0].location._model_location
+        is_timeseries = 'autoai-ts' in model_location
+
+        path_parts = model_location.split('model.pickle')
         if len(path_parts) == 1:
-            path = result_client_and_connection[0].location._model_location.split('model.zip')[0]
-            path = f"{path}pre_hpo_d_output/Pipeline1/"
+            path = model_location.split('model.zip')[0]
+            if is_timeseries:
+                path = f"{path}after_pipeline_execution/P1/"
+            else:
+                path = f"{path}pre_hpo_d_output/Pipeline1/"
+
 
         else:
-            path = result_client_and_connection[0].location._model_location.split('model.pickle')[0]
+            path = model_location.split('model.pickle')[0]
 
         path = f"{path}pipeline-model.json"
 
