@@ -22,7 +22,7 @@ import shutil
 import tarfile
 import logging
 
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 
 
 INSTANCE_DETAILS_TYPE = u'instance_details_type'
@@ -77,10 +77,10 @@ def meta_props_str_conv(meta_props):
 
 
 def get_url(url, headers, params=None, isIcp=False):
-    import requests
+    import ibm_watson_machine_learning._wrappers.requests as requests
 
     if isIcp:
-        return requests.get(url, headers=headers, params=params, verify=False)
+        return requests.get(url, headers=headers, params=params)
     else:
         return requests.get(url, headers=headers, params=params)
 
@@ -570,8 +570,7 @@ class NextResourceGenerator:
             response = requests.get(
                 url=f"{self.url}/{self.next_href}",
                 headers=self.wml_client._get_headers(),
-                params=self.params if self.params is not None else self.wml_client.params(),
-                verify=not self.wml_client.ICP
+                params=self.params if self.params is not None else self.wml_client.params()
             )
             details_json = self.wml_client.training._handle_response(200, "Get next details", response)
 
