@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 from ibm_watson_machine_learning.utils import SPACES_DETAILS_TYPE, INSTANCE_DETAILS_TYPE, MEMBER_DETAILS_TYPE,DATA_ASSETS_DETAILS_TYPE, STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv, str_type_conv, get_file_from_cos
 from ibm_watson_machine_learning.metanames import VolumeMetaNames
 from ibm_watson_machine_learning.wml_resource import WMLResource
@@ -68,7 +68,7 @@ class Volume(WMLResource):
                                     headers=self._client._get_headers(zen=True))
         else:
             response = requests.get(self._client.service_instance._href_definitions.volume_href(volume_id),
-                                      headers=self._client._get_headers(zen=True), verify=False)
+                                      headers=self._client._get_headers(zen=True))
         if response.status_code == 200:
             return response.json()
         else:
@@ -178,8 +178,7 @@ class Volume(WMLResource):
             else:
                 creation_response = requests.post(self._client.service_instance._href_definitions.volumes_href(),
                         headers=self._client._get_headers(zen=True),
-                        json=input_meta,
-                        verify=False
+                        json=input_meta
                     )
             if creation_response.status_code == 200:
                 volume_id_details = creation_response.json()
@@ -225,20 +224,12 @@ class Volume(WMLResource):
         # Start the volume  service
         start_data = {}
         try:
-            if not self._ICP:
-                start_data = {}
-                creation_response = requests.post(
-                    start_url,
-                    headers=self._client._get_headers(zen=True),
-                    json=start_data
-                )
-            else:
-                creation_response = requests.post(
-                   start_url,
-                    headers=self._client._get_headers(zen=True),
-                    json=start_data,
-                    verify=False
-                )
+            start_data = {}
+            creation_response = requests.post(
+                start_url,
+                headers=self._client._get_headers(zen=True),
+                json=start_data
+            )
             if creation_response.status_code == 200:
                 print("Volume Service started")
             elif creation_response.status_code == 500:
@@ -304,61 +295,6 @@ class Volume(WMLResource):
             print("Failed to upload the file to  volume. Try again.")
             return "FAILED"
 
-       # header = {'Authorization': zentoken}
-       #  dirfiles = {'file': None}
-       #  if not self._ICP:
-       #      upload_dir_response = requests.post(
-       #          upload_url,
-       #          headers=header,
-       #          files=dirfiles
-       #          )
-       #  else:
-       #      upload_dir_response = requests.put(
-       #          upload_url,
-       #          headers=header,
-       #          files=dirfiles,
-       #          verify=False
-       #      )
-       #  if upload_dir_response.status_code != 200:
-       #      raise WMLClientError("Failed to create a directory to upload the file to  volume. Try again.")
-       #
-       #
-       #  filename_to_upload = file_path.split('/')[-1]
-       #  #upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name) +
-       #  upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name) + "wmldir/"
-       # #  #upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name) +
-       # #  import urllib
-       # #  upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name)  + urllib.parse.quote(filename_to_upload, safe='')
-       # #  print(upload_url_file)
-       #  import urllib
-       #  upload_url_file = self._client.service_instance._href_definitions.volume_upload_href(name) + filename_to_upload
-       #  #upload_url_file = urllib.parse.quote(self._client.service_instance._href_definitions.volume_upload_href(name) + "wmldir/" +filename_to_upload, safe='')
-       #  files = {'upload_file': (filename_to_upload,  open(file_path, 'rb'))}
-       #
-       #  with open(file_path, 'rb') as f:
-       #      if not self._ICP:
-       #          upload_response = requests.put(
-       #              upload_url_file,
-       #              headers=header,
-       #              files=files
-       #              )
-       #      else:
-       #          f = {'upload_file': (filename_to_upload, open(file_path, 'rb'), 'csv', {'Expires': '0'})}
-       #          # with open(file_path, 'rb') as f:
-       #          #     fdata = f.read()
-       #              # upload_response = requests.put(
-       #              #     upload_url_file,
-       #              #     files={'file': (filename_to_upload, fdata, 'text/csv', {'Expires': '0'})},
-       #              #     #files=files,
-       #              #     #files=f,
-       #              #     headers=header,
-       #              #     verify=False
-       #              # )
-       #          # header.update({'Accept': 'text/csv'})#',image/png,image/gif',
-       #          # upload_response = requests.request("PUT", upload_url_file,
-       #          #                  files=f,
-       #          #                  headers=header, verify=False)
-
     def list(self):
         """
            List stored scripts. If limit is set to None there will be only first 50 records shown.
@@ -386,7 +322,7 @@ class Volume(WMLResource):
         if not self._ICP:
             response = requests.get(href, params=params, headers=self._client._get_headers(zen=True))
         else:
-            response = requests.get(href, params=params, headers=self._client._get_headers(zen=True), verify=False)
+            response = requests.get(href, params=params, headers=self._client._get_headers(zen=True))
         asset_details = self._handle_response(200, u'list volumes', response)
         asset_list = asset_details.get('service_instances')
         volume_values = [
@@ -496,7 +432,7 @@ class Volume(WMLResource):
                                        headers=self._client._get_headers(zen=True))
         else:
             response = requests.delete(self._client.service_instance._href_definitions.volume_href(volume_id),
-                                      headers=self._client._get_headers(zen=True), verify=False)
+                                      headers=self._client._get_headers(zen=True))
 
         if response.status_code == 200 or response.status_code == 204:
             print("Successfully deleted volume service.")
@@ -537,7 +473,7 @@ class Volume(WMLResource):
                                        headers=self._client._get_headers(zen=True))
         else:
             response = requests.delete(self._client.service_instance._href_definitions.volume_service_href(volume_name),
-                                       headers=self._client._get_headers(zen=True), verify=False)
+                                       headers=self._client._get_headers(zen=True))
         if response.status_code == 200:
             print("Successfully stopped volume service.")
             return "SUCCESS"
